@@ -1,7 +1,7 @@
 """
 Type annotations for amplifybackend service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/type_defs.html)
 
 Usage::
 
@@ -14,10 +14,9 @@ Usage::
 import sys
 from typing import Any, Dict, List, Mapping, Sequence
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AdditionalConstraintsElementType,
+    AuthenticatedElementType,
     AuthResourcesType,
     DeliveryMethodType,
     MFAModeType,
@@ -29,6 +28,7 @@ from .literals import (
     ResolutionStrategyType,
     SignInMethodType,
     StatusType,
+    UnAuthenticatedElementType,
 )
 
 if sys.version_info >= (3, 9):
@@ -49,6 +49,7 @@ __all__ = (
     "BackendAuthAppleProviderConfigTypeDef",
     "BackendAuthSocialProviderConfigTypeDef",
     "BackendJobRespObjTypeDef",
+    "BackendStoragePermissionsTypeDef",
     "CloneBackendRequestRequestTypeDef",
     "CloneBackendResponseTypeDef",
     "CreateBackendAPIRequestRequestTypeDef",
@@ -66,6 +67,9 @@ __all__ = (
     "CreateBackendConfigResponseTypeDef",
     "CreateBackendRequestRequestTypeDef",
     "CreateBackendResponseTypeDef",
+    "CreateBackendStorageRequestRequestTypeDef",
+    "CreateBackendStorageResourceConfigTypeDef",
+    "CreateBackendStorageResponseTypeDef",
     "CreateTokenRequestRequestTypeDef",
     "CreateTokenResponseTypeDef",
     "DeleteBackendAPIRequestRequestTypeDef",
@@ -74,6 +78,8 @@ __all__ = (
     "DeleteBackendAuthResponseTypeDef",
     "DeleteBackendRequestRequestTypeDef",
     "DeleteBackendResponseTypeDef",
+    "DeleteBackendStorageRequestRequestTypeDef",
+    "DeleteBackendStorageResponseTypeDef",
     "DeleteTokenRequestRequestTypeDef",
     "DeleteTokenResponseTypeDef",
     "EmailSettingsTypeDef",
@@ -89,13 +95,19 @@ __all__ = (
     "GetBackendJobResponseTypeDef",
     "GetBackendRequestRequestTypeDef",
     "GetBackendResponseTypeDef",
+    "GetBackendStorageRequestRequestTypeDef",
+    "GetBackendStorageResourceConfigTypeDef",
+    "GetBackendStorageResponseTypeDef",
     "GetTokenRequestRequestTypeDef",
     "GetTokenResponseTypeDef",
     "ImportBackendAuthRequestRequestTypeDef",
     "ImportBackendAuthResponseTypeDef",
-    "ListBackendJobsRequestListBackendJobsPaginateTypeDef",
+    "ImportBackendStorageRequestRequestTypeDef",
+    "ImportBackendStorageResponseTypeDef",
     "ListBackendJobsRequestRequestTypeDef",
     "ListBackendJobsResponseTypeDef",
+    "ListS3BucketsRequestRequestTypeDef",
+    "ListS3BucketsResponseTypeDef",
     "LoginAuthConfigReqObjTypeDef",
     "PaginatorConfigTypeDef",
     "RemoveAllBackendsRequestRequestTypeDef",
@@ -103,6 +115,7 @@ __all__ = (
     "RemoveBackendConfigRequestRequestTypeDef",
     "RemoveBackendConfigResponseTypeDef",
     "ResponseMetadataTypeDef",
+    "S3BucketInfoTypeDef",
     "SettingsTypeDef",
     "SmsSettingsTypeDef",
     "SocialProviderSettingsTypeDef",
@@ -121,6 +134,9 @@ __all__ = (
     "UpdateBackendConfigResponseTypeDef",
     "UpdateBackendJobRequestRequestTypeDef",
     "UpdateBackendJobResponseTypeDef",
+    "UpdateBackendStorageRequestRequestTypeDef",
+    "UpdateBackendStorageResourceConfigTypeDef",
+    "UpdateBackendStorageResponseTypeDef",
 )
 
 BackendAPIAppSyncAuthSettingsTypeDef = TypedDict(
@@ -215,6 +231,27 @@ class BackendJobRespObjTypeDef(
     pass
 
 
+_RequiredBackendStoragePermissionsTypeDef = TypedDict(
+    "_RequiredBackendStoragePermissionsTypeDef",
+    {
+        "Authenticated": Sequence[AuthenticatedElementType],
+    },
+)
+_OptionalBackendStoragePermissionsTypeDef = TypedDict(
+    "_OptionalBackendStoragePermissionsTypeDef",
+    {
+        "UnAuthenticated": Sequence[UnAuthenticatedElementType],
+    },
+    total=False,
+)
+
+
+class BackendStoragePermissionsTypeDef(
+    _RequiredBackendStoragePermissionsTypeDef, _OptionalBackendStoragePermissionsTypeDef
+):
+    pass
+
+
 CloneBackendRequestRequestTypeDef = TypedDict(
     "CloneBackendRequestRequestTypeDef",
     {
@@ -501,6 +538,50 @@ CreateBackendResponseTypeDef = TypedDict(
     },
 )
 
+CreateBackendStorageRequestRequestTypeDef = TypedDict(
+    "CreateBackendStorageRequestRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceConfig": "CreateBackendStorageResourceConfigTypeDef",
+        "ResourceName": str,
+    },
+)
+
+_RequiredCreateBackendStorageResourceConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendStorageResourceConfigTypeDef",
+    {
+        "Permissions": "BackendStoragePermissionsTypeDef",
+        "ServiceName": Literal["S3"],
+    },
+)
+_OptionalCreateBackendStorageResourceConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendStorageResourceConfigTypeDef",
+    {
+        "BucketName": str,
+    },
+    total=False,
+)
+
+
+class CreateBackendStorageResourceConfigTypeDef(
+    _RequiredCreateBackendStorageResourceConfigTypeDef,
+    _OptionalCreateBackendStorageResourceConfigTypeDef,
+):
+    pass
+
+
+CreateBackendStorageResponseTypeDef = TypedDict(
+    "CreateBackendStorageResponseTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "JobId": str,
+        "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 CreateTokenRequestRequestTypeDef = TypedDict(
     "CreateTokenRequestRequestTypeDef",
     {
@@ -598,6 +679,27 @@ DeleteBackendResponseTypeDef = TypedDict(
     },
 )
 
+DeleteBackendStorageRequestRequestTypeDef = TypedDict(
+    "DeleteBackendStorageRequestRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+        "ServiceName": Literal["S3"],
+    },
+)
+
+DeleteBackendStorageResponseTypeDef = TypedDict(
+    "DeleteBackendStorageResponseTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "JobId": str,
+        "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DeleteTokenRequestRequestTypeDef = TypedDict(
     "DeleteTokenRequestRequestTypeDef",
     {
@@ -778,6 +880,49 @@ GetBackendResponseTypeDef = TypedDict(
     },
 )
 
+GetBackendStorageRequestRequestTypeDef = TypedDict(
+    "GetBackendStorageRequestRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+    },
+)
+
+_RequiredGetBackendStorageResourceConfigTypeDef = TypedDict(
+    "_RequiredGetBackendStorageResourceConfigTypeDef",
+    {
+        "Imported": bool,
+        "ServiceName": Literal["S3"],
+    },
+)
+_OptionalGetBackendStorageResourceConfigTypeDef = TypedDict(
+    "_OptionalGetBackendStorageResourceConfigTypeDef",
+    {
+        "BucketName": str,
+        "Permissions": "BackendStoragePermissionsTypeDef",
+    },
+    total=False,
+)
+
+
+class GetBackendStorageResourceConfigTypeDef(
+    _RequiredGetBackendStorageResourceConfigTypeDef, _OptionalGetBackendStorageResourceConfigTypeDef
+):
+    pass
+
+
+GetBackendStorageResponseTypeDef = TypedDict(
+    "GetBackendStorageResponseTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceConfig": "GetBackendStorageResourceConfigTypeDef",
+        "ResourceName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetTokenRequestRequestTypeDef = TypedDict(
     "GetTokenRequestRequestTypeDef",
     {
@@ -835,32 +980,41 @@ ImportBackendAuthResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListBackendJobsRequestListBackendJobsPaginateTypeDef = TypedDict(
-    "_RequiredListBackendJobsRequestListBackendJobsPaginateTypeDef",
+_RequiredImportBackendStorageRequestRequestTypeDef = TypedDict(
+    "_RequiredImportBackendStorageRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
+        "ServiceName": Literal["S3"],
     },
 )
-_OptionalListBackendJobsRequestListBackendJobsPaginateTypeDef = TypedDict(
-    "_OptionalListBackendJobsRequestListBackendJobsPaginateTypeDef",
+_OptionalImportBackendStorageRequestRequestTypeDef = TypedDict(
+    "_OptionalImportBackendStorageRequestRequestTypeDef",
     {
-        "JobId": str,
-        "Operation": str,
-        "Status": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "BucketName": str,
     },
     total=False,
 )
 
 
-class ListBackendJobsRequestListBackendJobsPaginateTypeDef(
-    _RequiredListBackendJobsRequestListBackendJobsPaginateTypeDef,
-    _OptionalListBackendJobsRequestListBackendJobsPaginateTypeDef,
+class ImportBackendStorageRequestRequestTypeDef(
+    _RequiredImportBackendStorageRequestRequestTypeDef,
+    _OptionalImportBackendStorageRequestRequestTypeDef,
 ):
     pass
 
 
+ImportBackendStorageResponseTypeDef = TypedDict(
+    "ImportBackendStorageResponseTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "JobId": str,
+        "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListBackendJobsRequestRequestTypeDef = TypedDict(
     "_RequiredListBackendJobsRequestRequestTypeDef",
     {
@@ -896,6 +1050,23 @@ ListBackendJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListS3BucketsRequestRequestTypeDef = TypedDict(
+    "ListS3BucketsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListS3BucketsResponseTypeDef = TypedDict(
+    "ListS3BucketsResponseTypeDef",
+    {
+        "Buckets": List["S3BucketInfoTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 LoginAuthConfigReqObjTypeDef = TypedDict(
     "LoginAuthConfigReqObjTypeDef",
     {
@@ -976,6 +1147,15 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+S3BucketInfoTypeDef = TypedDict(
+    "S3BucketInfoTypeDef",
+    {
+        "CreationDate": str,
+        "Name": str,
+    },
+    total=False,
+)
+
 SettingsTypeDef = TypedDict(
     "SettingsTypeDef",
     {
@@ -1217,3 +1397,32 @@ UpdateBackendJobResponseTypeDef = TypedDict(
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
+
+UpdateBackendStorageRequestRequestTypeDef = TypedDict(
+    "UpdateBackendStorageRequestRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceConfig": "UpdateBackendStorageResourceConfigTypeDef",
+        "ResourceName": str,
+    },
+)
+
+UpdateBackendStorageResourceConfigTypeDef = TypedDict(
+    "UpdateBackendStorageResourceConfigTypeDef",
+    {
+        "Permissions": "BackendStoragePermissionsTypeDef",
+        "ServiceName": Literal["S3"],
+    },
+)
+
+UpdateBackendStorageResponseTypeDef = TypedDict(
+    "UpdateBackendStorageResponseTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "JobId": str,
+        "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
